jacinle.utils.printing
======================

.. automodule:: jacinle.utils.printing

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      PrintToStringContext
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      colored
      format_printable_data
      indent_text
      kvformat
      kvprint
      print2format
      print_filedoc
      print_to
      print_to_string
      stformat
      stprint
      suppress_output
      suppress_stderr
      suppress_stdout
      tabulate_dataclass
   
   

   
   
   








.. rubric:: Class PrintToStringContext
.. autoclass:: PrintToStringContext
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: colored

.. autofunction:: format_printable_data

.. autofunction:: indent_text

.. autofunction:: kvformat

.. autofunction:: kvprint

.. autofunction:: print2format

.. autofunction:: print_filedoc

.. autofunction:: print_to

.. autofunction:: print_to_string

.. autofunction:: stformat

.. autofunction:: stprint

.. autofunction:: suppress_output

.. autofunction:: suppress_stderr

.. autofunction:: suppress_stdout

.. autofunction:: tabulate_dataclass


